@@ -11,7 +11,7 @@ expect_equal() {
     echo "${2}" > "${expected_out}"
     echo "${output}" > "${out}"
     echo "FAIL: $1"
-    diff -u "$expected_out" "$out"
+    diff  --label Expected --label Actual -u "$expected_out" "$out"
     rm -f "$expected_out" "$out"
     return 1
   fi
